@@ -1,3 +1,5 @@
+from __future__ import absolute_import, print_function, division
+
 import math
 import struct
 
@@ -268,6 +270,7 @@ class Angle(object):
         else:
             return div
 
+    __truediv__ = __div__
 
 def smart_round_angle_sexagesimal(x, latitude=False, hours=False):
 
