@@ -22,6 +22,7 @@ try:
     import pyfits
     HDU_TYPES.append(pyfits.PrimaryHDU)
     HDU_TYPES.append(pyfits.ImageHDU)
+    HDU_TYPES.append(pyfits.CompImageHDU)
     HDULIST_TYPES.append(pyfits.HDUList)
     del pyfits
 except ImportError:
@@ -38,6 +39,7 @@ except ImportError:
 from astropy.io import fits
 HDU_TYPES.append(fits.PrimaryHDU)
 HDU_TYPES.append(fits.ImageHDU)
+HDU_TYPES.append(fits.CompImageHDU)
 HDULIST_TYPES.append(fits.HDUList)
 
 from astropy.wcs import WCS
@@ -55,6 +57,7 @@ from matplotlib.patches import Circle, Rectangle, Ellipse, Polygon, FancyArrow
 from matplotlib.collections import PatchCollection, LineCollection
 
 from astropy import log
+import astropy.utils.exceptions as aue
 
 from . import contour_util
 from . import convolve_util
@@ -220,6 +223,11 @@ class FITSFigure(Layers, Regions, Deprecated):
 
         if isinstance(data, WCS_TYPES):
             wcs = data
+            if not hasattr(wcs, 'naxis1'):
+                raise aue.AstropyDeprecationWarning('WCS no longer stores information about NAXISn '
+                                                    'so it is not possibly to instantiate a FITSFigure '
+                                                    'from WCS alone')
+
             if wcs.naxis != 2:
                 raise ValueError("FITSFigure initialization via WCS objects can only be done with 2-dimensional WCS objects")
             header = wcs.to_header()
@@ -233,10 +241,10 @@ class FITSFigure(Layers, Regions, Deprecated):
             self._wcs.nx = nx
             self._wcs.ny = ny
             if downsample:
-                log.warn("downsample argument is ignored if data passed is a WCS object")
+                log.warning("downsample argument is ignored if data passed is a WCS object")
                 downsample = False
             if north:
-                log.warn("north argument is ignored if data passed is a WCS object")
+                log.warning("north argument is ignored if data passed is a WCS object")
                 north = False
         else:
             self._data, self._header, self._wcs = self._get_hdu(data, hdu, north, \
@@ -337,7 +345,7 @@ class FITSFigure(Layers, Regions, Deprecated):
                 for alt_hdu in range(len(hdulist)):
                     if isinstance(hdulist[alt_hdu], HDU_TYPES):
                         if hdulist[alt_hdu].data is not None:
-                            log.warn("hdu=%i does not contain any data, using hdu=%i instead" % (hdu, alt_hdu))
+                            log.warning("hdu=%i does not contain any data, using hdu=%i instead" % (hdu, alt_hdu))
                             hdu = hdulist[alt_hdu]
                             found = True
                             break
@@ -506,10 +514,10 @@ class FITSFigure(Layers, Regions, Deprecated):
 
     @auto_refresh
     def show_grayscale(self, vmin=None, vmid=None, vmax=None,
-                            pmin=0.25, pmax=99.75,
-                            stretch='linear', exponent=2, invert='default',
-                            smooth=None, kernel='gauss', aspect='equal',
-                            interpolation='nearest'):
+                       pmin=0.25, pmax=99.75,
+                       stretch='linear', exponent=2, invert='default',
+                       smooth=None, kernel='gauss', aspect='equal',
+                       interpolation='nearest'):
         '''
         Show a grayscale image of the FITS file.
 
@@ -706,7 +714,10 @@ class FITSFigure(Layers, Regions, Deprecated):
                                                        smooth=smooth,
                                                        kernel=kernel))
         else:
-            self.image = self._ax1.imshow(convolve_util.convolve(self._data, smooth=smooth, kernel=kernel), cmap=cmap, interpolation=interpolation, origin='lower', extent=self._extent, norm=normalizer, aspect=aspect)
+            self.image = self._ax1.imshow(
+                convolve_util.convolve(self._data, smooth=smooth, kernel=kernel),
+                cmap=cmap, interpolation=interpolation, origin='lower',
+                extent=self._extent, norm=normalizer, aspect=aspect)
 
         xmin, xmax = self._ax1.get_xbound()
         if xmin == 0.0:
@@ -767,7 +778,7 @@ class FITSFigure(Layers, Regions, Deprecated):
                 raise ImportError("The Python Imaging Library (PIL) is required to read in RGB images")
 
         if flip:
-            log.warn("Note that show_rgb should now correctly flip RGB images, so the flip= argument is now deprecated. If you still need to flip an image vertically or horizontally, you can use the vertical_flip= and horizontal_flip arguments instead.")
+            log.warning("Note that show_rgb should now correctly flip RGB images, so the flip= argument is now deprecated. If you still need to flip an image vertically or horizontally, you can use the vertical_flip= and horizontal_flip arguments instead.")
 
         if filename is None:
             if hasattr(self, '_rgb_image'):
@@ -791,7 +802,7 @@ class FITSFigure(Layers, Regions, Deprecated):
         self.image = self._ax1.imshow(image, extent=self._extent, interpolation=interpolation, origin='upper')
 
     @auto_refresh
-    def show_contour(self, data, hdu=0, layer=None, levels=5, filled=False, cmap=None, colors=None, returnlevels=False, convention=None, dimensions=[0, 1], slices=[], smooth=None, kernel='gauss', overlap=False, **kwargs):
+    def show_contour(self, data=None, hdu=0, layer=None, levels=5, filled=False, cmap=None, colors=None, returnlevels=False, convention=None, dimensions=[0, 1], slices=[], smooth=None, kernel='gauss', overlap=False, **kwargs):
         '''
         Overlay contours on the current plot.
 
@@ -888,8 +899,15 @@ class FITSFigure(Layers, Regions, Deprecated):
         elif not colors:
             cmap = mpl.cm.get_cmap('jet')
 
-        data_contour, header_contour, wcs_contour = self._get_hdu(data, hdu, False, \
-            convention=convention, dimensions=dimensions, slices=slices)
+        if data is not None:
+            data_contour, header_contour, wcs_contour = self._get_hdu(data, \
+                    hdu, False, convention=convention, dimensions=dimensions, \
+                    slices=slices)
+        else:
+            data_contour = self._data
+            header_contour = self._header
+            wcs_contour = self._wcs
+
         wcs_contour.nx = header_contour['NAXIS%i' % (dimensions[0] + 1)]
         wcs_contour.ny = header_contour['NAXIS%i' % (dimensions[1] + 1)]
 
@@ -981,10 +999,10 @@ class FITSFigure(Layers, Regions, Deprecated):
         ----------
 
         xw : list or `~numpy.ndarray`
-            The x postions of the circles (in world coordinates)
+            The x positions of the centers of the circles (in world coordinates)
 
         yw : list or `~numpy.ndarray`
-            The y positions of the circles (in world coordinates)
+            The y positions of the centers of the circles (in world coordinates)
 
         radius : int or float or list or `~numpy.ndarray`
             The radii of the circles (in world coordinates)
@@ -1054,10 +1072,10 @@ class FITSFigure(Layers, Regions, Deprecated):
         ----------
 
         xw : list or `~numpy.ndarray`
-            The x postions of the ellipses (in world coordinates)
+            The x positions of the centers of the ellipses (in world coordinates)
 
         yw : list or `~numpy.ndarray`
-            The y positions of the ellipses (in world coordinates)
+            The y positions of the centers of the ellipses (in world coordinates)
 
         width : int or float or list or `~numpy.ndarray`
             The width of the ellipse (in world coordinates)
@@ -1146,10 +1164,10 @@ class FITSFigure(Layers, Regions, Deprecated):
         ----------
 
         xw : list or `~numpy.ndarray`
-            The x postions of the rectangles (in world coordinates)
+            The x positions of the centers of the rectangles (in world coordinates)
 
         yw : list or `~numpy.ndarray`
-            The y positions of the rectangles (in world coordinates)
+            The y positions of the centers of the rectangles (in world coordinates)
 
         width : int or float or list or `~numpy.ndarray`
             The width of the rectangle (in world coordinates)
