@@ -1,7 +1,11 @@
 from __future__ import absolute_import, print_function, division
 
 import numpy as np
-from astropy.nddata import convolve as nddata_convolve, make_kernel
+try:
+    from astropy.convolution import convolve as astropy_convolve, Gaussian2DKernel, Box2DKernel
+    make_kernel = None
+except ImportError:
+    from astropy.nddata import convolve as astropy_convolve, make_kernel
 
 
 def convolve(image, smooth=3, kernel='gauss'):
@@ -21,10 +25,16 @@ def convolve(image, smooth=3, kernel='gauss'):
     image_fixed[np.isinf(image)] = np.nan
 
     if kernel == 'gauss':
-        kernel = make_kernel((smooth * 5, smooth * 5), smooth, 'gaussian')
+        if make_kernel is None:
+            kernel = Gaussian2DKernel(smooth, x_size=smooth * 5, y_size=smooth * 5)
+        else:
+            kernel = make_kernel((smooth * 5, smooth * 5), smooth, 'gaussian')
     elif kernel == 'box':
-        kernel = make_kernel((smooth * 5, smooth * 5), smooth, 'boxcar')
+        if make_kernel is None:
+            kernel = Box2DKernel(smooth, x_size=smooth * 5, y_size=smooth * 5)
+        else:
+            kernel = make_kernel((smooth * 5, smooth * 5), smooth, 'boxcar')
     else:
         kernel = kernel
 
-    return nddata_convolve(image, kernel, boundary='extend')
+    return astropy_convolve(image, kernel, boundary='extend')
