@@ -50,7 +50,7 @@ class WCS(AstropyWCS):
                     coords.append(np.repeat(self._slices[s], xpix.shape))
                     s += 1
             coords = np.vstack(coords).transpose()
-            result = AstropyWCS.wcs_pix2sky(self, coords, 1)
+            result = AstropyWCS.wcs_pix2world(self, coords, 1)
             self._mean_world = np.mean(result, axis=0)
             # result = result.transpose()
             # result = result.reshape((result.shape[0],) + (self.ny, self.nx))
@@ -120,13 +120,13 @@ class WCS(AstropyWCS):
         else:
             raise AttributeError("Attribute %s does not exist" % attribute)
 
-    def wcs_sky2pix(self, x, y, origin):
+    def wcs_world2pix(self, x, y, origin):
         if self.naxis == 2:
             if self._dimensions[1] < self._dimensions[0]:
-                xp, yp = AstropyWCS.wcs_sky2pix(self, y, x, origin)
+                xp, yp = AstropyWCS.wcs_world2pix(self, y, x, origin)
                 return yp, xp
             else:
-                return AstropyWCS.wcs_sky2pix(self, x, y, origin)
+                return AstropyWCS.wcs_world2pix(self, x, y, origin)
         else:
             coords = []
             s = 0
@@ -143,20 +143,20 @@ class WCS(AstropyWCS):
             coords = np.vstack(coords).transpose()
 
             # Due to a bug in pywcs, we need to loop over each coordinate
-            # result = AstropyWCS.wcs_sky2pix(self, coords, origin)
+            # result = AstropyWCS.wcs_world2pix(self, coords, origin)
             result = np.zeros(coords.shape)
             for i in range(result.shape[0]):
-                result[i:i + 1, :] = AstropyWCS.wcs_sky2pix(self, coords[i:i + 1, :], origin)
+                result[i:i + 1, :] = AstropyWCS.wcs_world2pix(self, coords[i:i + 1, :], origin)
 
             return result[:, self._dimensions[0]], result[:, self._dimensions[1]]
 
-    def wcs_pix2sky(self, x, y, origin):
+    def wcs_pix2world(self, x, y, origin):
         if self.naxis == 2:
             if self._dimensions[1] < self._dimensions[0]:
-                xw, yw = AstropyWCS.wcs_pix2sky(self, y, x, origin)
+                xw, yw = AstropyWCS.wcs_pix2world(self, y, x, origin)
                 return yw, xw
             else:
-                return AstropyWCS.wcs_pix2sky(self, x, y, origin)
+                return AstropyWCS.wcs_pix2world(self, x, y, origin)
         else:
             coords = []
             s = 0
@@ -169,7 +169,7 @@ class WCS(AstropyWCS):
                     coords.append(np.repeat(self._slices[s] + 0.5, x.shape))
                     s += 1
             coords = np.vstack(coords).transpose()
-            result = AstropyWCS.wcs_pix2sky(self, coords, origin)
+            result = AstropyWCS.wcs_pix2world(self, coords, origin)
             return result[:, self._dimensions[0]], result[:, self._dimensions[1]]
 
 
@@ -209,13 +209,19 @@ def convert_coords(x, y, input, output):
             x, y = b1950toj2000(x, y)
         elif equinox_in == 'j2000' and equinox_out == 'b1950':
             x, y = j2000tob1950(x, y)
+        elif equinox_in == equinox_out:
+            pass
         else:
             raise Exception("Cannot convert between equatorial coordinates for equinoxes %s and %s" % (equinox_in, equinox_out))
 
     else:
         raise Exception("Cannot (yet) convert between %s, %s and %s, %s" % (system_in['name'], equinox_in, system_out['name'], equinox_out))
 
-    return x, y
+    # Take into account inverted coordinates
+    if system_in['inverted'] is system_out['inverted']:
+        return x, y
+    else:
+        return y, x
 
 
 def precession_matrix(equinox1, equinox2, fk4=False):
@@ -454,25 +460,25 @@ def pixel_scale(wcs):
 
 def world2pix(wcs, x_world, y_world):
     if np.isscalar(x_world) and np.isscalar(y_world):
-        x_pix, y_pix = wcs.wcs_sky2pix(np.array([x_world]), np.array([y_world]), 1)
+        x_pix, y_pix = wcs.wcs_world2pix(np.array([x_world]), np.array([y_world]), 1)
         return x_pix[0], y_pix[0]
     elif (type(x_world) == list) and (type(y_world) == list):
-        x_pix, y_pix = wcs.wcs_sky2pix(np.array(x_world), np.array(y_world), 1)
+        x_pix, y_pix = wcs.wcs_world2pix(np.array(x_world), np.array(y_world), 1)
         return x_pix.tolist(), y_pix.tolist()
     elif isinstance(x_world, np.ndarray) and isinstance(y_world, np.ndarray):
-        return wcs.wcs_sky2pix(x_world, y_world, 1)
-    else:            
+        return wcs.wcs_world2pix(x_world, y_world, 1)
+    else:
         raise Exception("world2pix should be provided either with two scalars, two lists, or two numpy arrays")
 
 
 def pix2world(wcs, x_pix, y_pix):
     if np.isscalar(x_pix) and np.isscalar(y_pix):
-        x_world, y_world = wcs.wcs_pix2sky(np.array([x_pix]), np.array([y_pix]), 1)
+        x_world, y_world = wcs.wcs_pix2world(np.array([x_pix]), np.array([y_pix]), 1)
         return x_world[0], y_world[0]
     elif (type(x_pix) == list) and (type(y_pix) == list):
-        x_world, y_world = wcs.wcs_pix2sky(np.array(x_pix), np.array(y_pix), 1)
+        x_world, y_world = wcs.wcs_pix2world(np.array(x_pix), np.array(y_pix), 1)
         return x_world.tolist(), y_world.tolist()
     elif isinstance(x_pix, np.ndarray) and isinstance(y_pix, np.ndarray):
-        return wcs.wcs_pix2sky(x_pix, y_pix, 1)
+        return wcs.wcs_pix2world(x_pix, y_pix, 1)
     else:
         raise Exception("pix2world should be provided either with two scalars, two lists, or two numpy arrays")
